@@ -4,7 +4,7 @@ import (
 	"testing"
 
 	tree_sitter "github.com/tree-sitter/go-tree-sitter"
-	tree_sitter_markdown "github.com/tree-sitter/tree-sitter-markdown/bindings/go"
+	tree_sitter_markdown "github.com/tree-sitter-grammars/tree-sitter-markdown/bindings/go"
 )
 
 func TestCanLoadBlockGrammar(t *testing.T) {
